==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/WebhooksIntegrationEncoding.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** Encoding type. Can be given either <code>json</code> or <code>form</code>. */
@JsonSerialize(using = WebhooksIntegrationEncoding.WebhooksIntegrationEncodingSerializer.class)
public class WebhooksIntegrationEncoding {

  public static final WebhooksIntegrationEncoding JSON = new WebhooksIntegrationEncoding("json");
  public static final WebhooksIntegrationEncoding FORM = new WebhooksIntegrationEncoding("form");

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("json", "form"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  WebhooksIntegrationEncoding(String value) {
    this.value = value;
  }

  public static class WebhooksIntegrationEncodingSerializer
      extends StdSerializer<WebhooksIntegrationEncoding> {
    public WebhooksIntegrationEncodingSerializer(Class<WebhooksIntegrationEncoding> t) {
      super(t);
    }

    public WebhooksIntegrationEncodingSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        WebhooksIntegrationEncoding value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this WebhooksIntegrationEncoding object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((WebhooksIntegrationEncoding) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static WebhooksIntegrationEncoding fromValue(String value) {
    return new WebhooksIntegrationEncoding(value);
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v1/model/WebhooksIntegrationEncoding.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** Encoding type. Can be given either <code>json</code> or <code>form</code>. */
@JsonSerialize(using = WebhooksIntegrationEncoding.WebhooksIntegrationEncodingSerializer.class)
public class WebhooksIntegrationEncoding extends ModelEnum<String> {

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("json", "form"));

  public static final WebhooksIntegrationEncoding JSON = new WebhooksIntegrationEncoding("json");
  public static final WebhooksIntegrationEncoding FORM = new WebhooksIntegrationEncoding("form");

  WebhooksIntegrationEncoding(String value) {
    super(value, allowedValues);
  }

  public static class WebhooksIntegrationEncodingSerializer
      extends StdSerializer<WebhooksIntegrationEncoding> {
    public WebhooksIntegrationEncodingSerializer(Class<WebhooksIntegrationEncoding> t) {
      super(t);
    }

    public WebhooksIntegrationEncodingSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        WebhooksIntegrationEncoding value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static WebhooksIntegrationEncoding fromValue(String value) {
    return new WebhooksIntegrationEncoding(value);
  }
}
